package
Version:
v0.2.8
Opens a new window with list of versions in this module.
Published: May 14, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Nickname string `json:"nickname"`
DataDir string `json:"data_dir"`
PrivateKeyB64 string `json:"private_key_b64,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.